@@ -21,7 +21,7 @@
 #include <QInputDialog>
 
 KShellCmdPlugin::KShellCmdPlugin(QObject *parent, const QVariantList &)
-    : KParts::Plugin(parent)
+    : KonqParts::Plugin(parent)
 {
     if (!KAuthorized::authorize(QStringLiteral("shell_access"))) {
         return;
@@ -89,7 +89,7 @@ void KShellCmdPlugin::slotExecuteShellCommand()
     }
 }
 
-K_PLUGIN_FACTORY(KonqShellCmdPluginFactory, registerPlugin<KShellCmdPlugin>();)
+K_PLUGIN_CLASS_WITH_JSON(KShellCmdPlugin, "kshellcmdplugin.json")
 
 #include "kshellcmdplugin.moc"
 
